@@ -5,7 +5,7 @@ from pydantic import BaseModel, Field
 class TargetField(BaseModel):
     type: typing.Literal["string"]  # only string types supported for the moment
     title: typing.Optional[str]
-    description: typing.Optional[str]
+    usage: typing.Optional[str]
     resource: typing.Optional[str] = Field(
         description="If specified, the type of the resource the field should be populated from."
     )
@@ -21,7 +21,7 @@ class Target(BaseModel):
 
 
 class Meta(BaseModel):
-    framework: str = Field(
+    framework: typing.Optional[str] = Field(
         description="The Provider Developer Kit framework version which published the schema."
     )
 
